%define vdsm_reg vdsm-reg
%define vdsm_name vdsm
%define vdsm_bootstrap vdsm-bootstrap
%include %{_rpmconfigdir}/macros.python

Name:           %{vdsm_name}
Version:        4.9.0
Release:        0.200.g2fc4e63%{?dist}%{?extra_release}
Summary:        Virtual Desktop Server Manager

Group:          Applications/System
License:        GPLv2+
Url:            http://git.fedorahosted.org/git/?p=vdsm.git
Source0:        %{vdsm_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: python

Requires: python which
Requires: sudo >= 1.7.3
Requires: logrotate
Requires: python-ethtool
Requires: nfs-utils dmidecode
Requires: lvm2 >= 2.02.72-8

%if 0%{?rhel}
Requires: qemu-kvm >= 2:0.12.1.2-2.189
Requires: qemu-img >= 2:0.12.1.2-2.189
Requires: libvirt >= 0.9.4-13
Requires: libvirt-python >= 0.9.4-13
Requires: iscsi-initiator-utils >= 6.2.0.872-15
Requires: device-mapper-multipath >= 0.4.9-31
%else
Requires: qemu-kvm >= 2:0.15.0-4
Requires: qemu-img >= 2:0.15.0-4
Requires: libvirt >= 0.9.6-2
Requires: libvirt-python >= 0.9.6-2
Requires: iscsi-initiator-utils >= 6.2.0.872-12
Requires: device-mapper-multipath >= 0.4.9-18
%endif

Requires: psmisc >= 22.6-15
Requires: fence-agents
Requires: bridge-utils
Requires: sos
Requires: dosfstools
Requires: policycoreutils-python
Requires: kernel >= 2.6.32-198
Requires(post): cyrus-sasl-lib
BuildRequires: pyflakes
Conflicts: selinux-policy-targeted < 3.7.19-80.el6

%description
The VDSM service is required by a Virtualization Manager to manage the
Linux hosts. VDSM manages and monitors the host's storage, memory and
networks as well as virtual machine creation, other host administration
tasks, statistics gathering, and log collection.

%package hook-vhostmd
Summary:        VDSM hook set for interaction with vhostmd
Requires:       vhostmd
BuildArch:      noarch

%description hook-vhostmd
VDSM hook to use vhostmd per VM according to Virtualization Manager requests.

%package hook-faqemu
Summary:        Fake qemu process for VDSM quality assurance
BuildArch:      noarch

%description hook-faqemu
VDSM hook used for testing VDSM with multiple fake virtual machines without
running real guests.

%package debug-plugin
Summary:        VDSM Debug Plugin
Requires:       vdsm
BuildArch:      noarch

%description debug-plugin
Used by the trained monkeys at Red Hat to insert chaos and mayhem in to VDSM.

%package cli
Summary:        VDSM command line interface
BuildArch:      noarch

%description cli
Call VDSM commands from the command line. Used for testing and debugging.

%package bootstrap
Summary:        VDSM bootstrapping package
BuildArch:      noarch

%description bootstrap
VDSM bootstrapping package. Used for delivering the bootstap code onto the
Virtualization Manager.

%package reg
Summary:        VDSM registration package
BuildArch:      noarch

Requires: %{name} = %{version}-%{release}
Requires: traceroute

%description reg
VDSM registration package. Used to register a Linux host to a Virtualization
Manager.

%prep
%setup -q

%build
%configure
make

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install

%if 0%{?rhel}
# this is not commonplace, but we want /var/log/core to be a world-writable
# dropbox for core dumps.
install -dDm 1777 %{buildroot}%{_localstatedir}/log/core

# faqemu symlinks
ln -s vdsm-faqemu %{buildroot}%{_bindir}/qemu
ln -s vdsm-faqemu %{buildroot}%{_bindir}/qemu-system-x86_64
%endif

%check
make check

%clean
rm -rf %{buildroot}

%pre
/usr/bin/getent passwd vdsm >/dev/null || \
    /usr/sbin/useradd -r -u 36 -g kvm -d /var/lib/vdsm \
        -s /sbin/nologin -c "Node Virtualization Manager" vdsm
/usr/sbin/usermod -a -G qemu vdsm

%post
tmp_sudoers=$(mktemp)
/bin/cp -a /etc/sudoers $tmp_sudoers
/bin/sed -i -e "/# vdsm/,/# end vdsm/d" $tmp_sudoers

if ! /bin/grep -q "^#includedir /etc/sudoers.d" "$tmp_sudoers";
then
    /bin/cat >> $tmp_sudoers <<EOF
# vdsm customizations
#include /etc/sudoers.d/50_vdsm
# end vdsm customizations
EOF
fi

if outerr=$(/usr/sbin/visudo -c -f $tmp_sudoers 2>&1) ; then
    /bin/cp -a $tmp_sudoers /etc/sudoers
else
    /bin/echo "Failed to add vdsm section to /etc/sudoers" 1>&2
    /bin/echo "$outerr" 1>&2
fi
rm -f $tmp_sudoers

# vdsm is intentionally on by default.
/sbin/chkconfig --add vdsmd

# create vdsm "secret" password for libvirt, if none exists
pfile=/etc/pki/%{vdsm_name}/keys/libvirt_password
if [[ ! -f "$pfile" ]];
then
    umask 077
    /bin/echo -n shibboleth > "$pfile"
    /bin/chown vdsm:kvm "$pfile"
    new_pwd=1
fi
if ! /usr/sbin/sasldblistusers2 -f /etc/libvirt/passwd.db 2> /dev/null | \
    /bin/grep -q '^vdsm@rhevh\b' || [[ -n "$new_pwd" ]] ;
then
    /usr/sbin/saslpasswd2 -p -a libvirt vdsm@rhevh < "$pfile"
fi

%preun
if [ "$1" -eq 0 ]
then
    /sbin/service vdsmd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vdsmd

    tmp_sudoers=$(mktemp)
    /bin/cp -a /etc/sudoers $tmp_sudoers
    /bin/sed -i -e "/# vdsm/,/# end vdsm/d" $tmp_sudoers /etc/logrotate.d/libvirtd
    if outerr=$(/usr/sbin/visudo -c -f $tmp_sudoers 2>&1) ; then
        /bin/cp -a $tmp_sudoers /etc/sudoers
    else
        /bin/echo "Failed to add vdsm section to /etc/sudoers" 1>&2
        /bin/echo "$outerr" 1>&2
    fi
    rm -f $tmp_sudoers

    /bin/sed -i '/# by vdsm$/d' \
        /etc/libvirt/libvirtd.conf \
        /etc/libvirt/qemu.conf \
        /etc/sysconfig/libvirtd \
        /etc/sysctl.conf

    /bin/sed -i '/# VDSM section begin/,/# VDSM section end/d' \
        /etc/sysctl.conf

    /usr/sbin/semanage boolean -m -S targeted -F /dev/stdin  << _EOF
virt_use_nfs=0
_EOF

    if selinuxenabled; then
        /usr/sbin/setsebool virt_use_nfs off
    fi

%if 0%{?rhel}
    if /sbin/initctl status libvirtd >/dev/null 2>/dev/null ; then
        /sbin/initctl stop libvirtd  >/dev/null 2>/dev/null
        rm -f /etc/init/libvirtd.conf

        /sbin/chkconfig libvirtd on
        /sbin/service libvirtd start >/dev/null
    fi
%endif
fi

%postun
if [ "$1" -ge 1 ]; then
    /sbin/service vdsmd condrestart > /dev/null 2>&1
fi
exit 0

%if 0%{?rhel}
%triggerun -- libvirt
if [ "$2" -eq "0" ]; then
    /sbin/initctl stop libvirtd > /dev/null 2>&1 || :
fi

%triggerpostun -- libvirt
if [ "$2" -ge "1" ]; then
    /sbin/initctl restart libvirtd > /dev/null 2>&1 || :
fi
%endif

%post reg
/sbin/chkconfig --add vdsm-reg

%preun reg
if [ "$1" -eq 0 ]
then
    /sbin/service vdsm-reg stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vdsm-reg
fi

%files
%defattr(-, root, root, -)
%doc COPYING README vdsm/vdsm.conf.sample
%{_initrddir}/vdsmd
%dir %{_libexecdir}/%{vdsm_name}
%dir %{_datadir}/%{vdsm_name}
%dir %{_datadir}/%{vdsm_name}/storage
%{_datadir}/%{vdsm_name}/define.py*
%{_datadir}/%{vdsm_name}/clientIF.py*
%{_datadir}/%{vdsm_name}/caps.py*
%{_datadir}/%{vdsm_name}/utils.py*
%{_datadir}/%{vdsm_name}/constants.py*
%{_datadir}/%{vdsm_name}/vm.py*
%{_datadir}/%{vdsm_name}/vdscli.py*
%{_datadir}/%{vdsm_name}/supervdsm.py*
%{_datadir}/%{vdsm_name}/supervdsmServer.py*
%{_datadir}/%{vdsm_name}/libvirtvm.py*
%{_datadir}/%{vdsm_name}/libvirtconnection.py*
%{_datadir}/%{vdsm_name}/hooks.py*
%{_datadir}/%{vdsm_name}/hooking.py*
%{_datadir}/%{vdsm_name}/libvirtev.py*
%{_datadir}/%{vdsm_name}/vdsm
%{_datadir}/%{vdsm_name}/vdsm-restore-net-config
%{_datadir}/%{vdsm_name}/vdsm-store-net-config
%{_datadir}/%{vdsm_name}/write-net-config
%{_datadir}/%{vdsm_name}/mk_sysprep_floppy
%{_datadir}/%{vdsm_name}/get-vm-pid
%{_datadir}/%{vdsm_name}/prepare-vmchannel
%config(noreplace) %{_sysconfdir}/%{vdsm_name}/logger.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/vdsm
%config(noreplace) %{_sysconfdir}/rwtab.d/vdsm
%{_sysconfdir}/sudoers.d/50_vdsm
%{_sysconfdir}/cron.hourly/vdsm-logrotate
%{_sysconfdir}/cron.d/vdsm-libvirt-logrotate
%{_datadir}/%{vdsm_name}/guestIF.py*
%{_datadir}/%{vdsm_name}/logUtils.py*
%{_datadir}/%{vdsm_name}/dsaversion.py*
%{_datadir}/%{vdsm_name}/pthread.py*
%{_datadir}/%{vdsm_name}/betterThreading.py*
%{_libexecdir}/%{vdsm_name}/persist-vdsm-hooks
%{_libexecdir}/%{vdsm_name}/unpersist-vdsm-hook
%{_datadir}/%{vdsm_name}/storage/__init__.py*
%{_datadir}/%{vdsm_name}/storage/dispatcher.py*
%{_datadir}/%{vdsm_name}/storage/storage_exception.py*
%{_datadir}/%{vdsm_name}/storage/sp.py*
%{_datadir}/%{vdsm_name}/storage/sd.py*
%{_datadir}/%{vdsm_name}/storage/spm.py*
%{_datadir}/%{vdsm_name}/storage/hsm.py*
%{_datadir}/%{vdsm_name}/storage/hba.py*
%{_datadir}/%{vdsm_name}/storage/safelease.py*
%{_datadir}/%{vdsm_name}/storage/image.py*
%{_datadir}/%{vdsm_name}/storage/fileSD.py*
%{_datadir}/%{vdsm_name}/storage/nfsSD.py*
%{_datadir}/%{vdsm_name}/storage/localFsSD.py*
%{_datadir}/%{vdsm_name}/storage/blockSD.py*
%{_datadir}/%{vdsm_name}/storage/volume.py*
%{_datadir}/%{vdsm_name}/storage/fileVolume.py*
%{_datadir}/%{vdsm_name}/storage/blockVolume.py*
%{_datadir}/%{vdsm_name}/storage/taskManager.py*
%{_datadir}/%{vdsm_name}/storage/threadPool.py*
%{_datadir}/%{vdsm_name}/storage/task.py*
%{_datadir}/%{vdsm_name}/storage/threadLocal.py*
%{_datadir}/%{vdsm_name}/storage/resourceManager.py*
%{_datadir}/%{vdsm_name}/storage/storage_connection.py*
%{_datadir}/%{vdsm_name}/storage/storage_mailbox.py*
%{_datadir}/%{vdsm_name}/storage/storageConstants.py*
%{_datadir}/%{vdsm_name}/storage/fileUtils.py*
%{_datadir}/%{vdsm_name}/storage/misc.py*
%{_datadir}/%{vdsm_name}/storage/lvm.py*
%{_datadir}/%{vdsm_name}/storage/resourceFactories.py*
%{_datadir}/%{vdsm_name}/storage/outOfProcess.py*
%{_datadir}/%{vdsm_name}/storage/processPool.py*
%{_datadir}/%{vdsm_name}/storage/iscsi.py*
%{_datadir}/%{vdsm_name}/storage/devicemapper.py*
%{_datadir}/%{vdsm_name}/storage/multipath.py*
%{_datadir}/%{vdsm_name}/storage/sdc.py*
%{_datadir}/%{vdsm_name}/storage/sdf.py*
%{_datadir}/%{vdsm_name}/storage/persistentDict.py*
%{_libexecdir}/%{vdsm_name}/safelease
%{_libexecdir}/%{vdsm_name}/spmprotect.sh
%{_libexecdir}/%{vdsm_name}/spmstop.sh
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_start
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_start
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_cont
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_cont
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_pause
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_pause
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_hibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_hibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_dehibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_dehibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_source
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_migrate_source
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_destination
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_migrate_destination
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vdsm_start
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vdsm_stop
%{_datadir}/%{vdsm_name}/configNetwork.py*
%{_datadir}/%{vdsm_name}/addNetwork
%{_datadir}/%{vdsm_name}/delNetwork
%{_datadir}/%{vdsm_name}/respawn
%{_datadir}/%{vdsm_name}/SecureXMLRPCServer.py*
%{_datadir}/%{vdsm_name}/get-conf-item
%{_datadir}/%{vdsm_name}/set-conf-item
%{_datadir}/%{vdsm_name}/kaxmlrpclib.py*
%{_datadir}/%{vdsm_name}/config.py*
%{_datadir}/%{vdsm_name}/ksm.py*
%{_datadir}/%{vdsm_name}/netinfo.py*
%{_datadir}/%{vdsm_name}/neterrors.py*
%{_sysconfdir}/udev/rules.d/12-vdsm-lvm.rules
%{py_sitedir}/sos/plugins/vdsm.py*
%{_mandir}/man8/vdsmd.8*
%if 0%{?rhel}
%dir %{_localstatedir}/log/core
%endif

%defattr(-, vdsm, qemu, -)
%dir %{_localstatedir}/lib/libvirt/qemu/channels

%defattr(-, vdsm, kvm, -)
%dir %{_sysconfdir}/pki/%{vdsm_name}
%dir %{_sysconfdir}/pki/%{vdsm_name}/keys
%dir %{_sysconfdir}/pki/%{vdsm_name}/certs
%dir %{_localstatedir}/lib/%{vdsm_name}
%dir %{_localstatedir}/lib/%{vdsm_name}/netconfback
%dir %{_localstatedir}/run/%{vdsm_name}
%dir %{_localstatedir}/run/%{vdsm_name}/pools
%dir %{_localstatedir}/log/%{vdsm_name}
%dir %{_localstatedir}/log/%{vdsm_name}/backup

%files hook-vhostmd
%defattr(-, root, root, -)
%doc COPYING
%{_sysconfdir}/sudoers.d/50_vdsm_hook_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_destination/50_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_dehibernate/50_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy/50_vhostmd

%files debug-plugin
%defattr(-, root, root, -)
%{_datadir}/%{vdsm_name}/vdsmDebugPlugin.py*

%files cli
%defattr(-, root, root, -)
%doc COPYING
%{_bindir}/vdsClient
%{_datadir}/%{vdsm_name}/vdsClient.py*
%{_sysconfdir}/bash_completion.d/vdsClient
%{_datadir}/%{vdsm_name}/vdscli.py*
%{_datadir}/%{vdsm_name}/dumpStorageTable.py*
%{_datadir}/%{vdsm_name}/SecureXMLRPCServer.py*
%{_mandir}/man1/vdsClient.1*

%files bootstrap
%defattr(-, root, root, -)
%doc COPYING
%{_datadir}/%{vdsm_bootstrap}/vds_bootstrap.py*
%{_datadir}/%{vdsm_bootstrap}/deployUtil.py*
%{_datadir}/%{vdsm_bootstrap}/vds_bootstrap_complete.py*

%files reg
%defattr(-, root, root, -)
%doc COPYING
%dir %{_sysconfdir}/%{vdsm_reg}
%dir %{_datadir}/%{vdsm_reg}
%config(noreplace) %{_sysconfdir}/logrotate.d/vdsm-reg
%config(noreplace) %{_sysconfdir}/%{vdsm_reg}/vdsm-reg.conf
%config(noreplace) %{_sysconfdir}/%{vdsm_reg}/logger.conf
%{_sysconfdir}/init.d/vdsm-reg
%{_datadir}/%{vdsm_reg}/vdsm-reg-setup
%{_datadir}/%{vdsm_reg}/define.py*
%{_datadir}/%{vdsm_reg}/vdsm-complete
%{_datadir}/%{vdsm_reg}/vdsm-gen-cert
%{_datadir}/%{vdsm_reg}/vdsm-upgrade
%{_datadir}/%{vdsm_reg}/config.py*
%{_datadir}/%{vdsm_reg}/deployUtil.py*
%{_datadir}/%{vdsm_reg}/createDaemon.py*
%{py_sitedir}/ovirt_config_setup/rhevm.py*
%{_datadir}/%{vdsm_reg}/save-config
%{_sysconfdir}/ovirt-config-boot.d/vdsm-config
%{_sysconfdir}/ovirt-commandline.d/vdsm-reg
%{_sysconfdir}/cron.hourly/vdsm-reg-logrotate
%{_mandir}/man8/vdsm-reg.8*

%defattr(-, vdsm, kvm,-)
%dir %{_var}/log/%{vdsm_reg}

%files hook-faqemu
%defattr(-, root, root, -)
%doc COPYING
%{_bindir}/vdsm-faqemu
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/10_faqemu
%if 0%{?rhel}
%{_bindir}/qemu
%{_bindir}/qemu-system-x86_64
%endif

%changelog
* Wed Oct 12 2011 Federico Simoncelli <fsimonce@redhat.com> - 4.9.0-0
- Initial upstream release

* Thu Nov 02 2006 Simon Grinberg <simong@qumranet.com> -  0.0-1
- Initial build
